<?php

namespace Drupal\neutrino_api_email_validator\Plugin\rest\resource;

use Drupal\rest\Plugin\ResourceBase;
use Drupal\rest\ResourceResponse;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Provides a REST resource for email validation.
 *
 * @RestResource(
 *   id = "neutrino_api_email_validator",
 *   label = @Translation("Neutrino email validator"),
 *   uri_paths = {
 *     "canonical" = "/neutrino-api/email-validate/{email}"
 *   }
 * )
 */
class NeutrinoEmailValidator extends ResourceBase {

  /**
   * The neutrino email validator service.
   *
   * @var \Drupal\neutrino_api_email_validator\NeutrinoEmailValidatorInterface
   */
  protected $emailValidator;

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container, array $configuration, $plugin_id, $plugin_definition) {
    $instance = parent::create($container, $configuration, $plugin_id, $plugin_definition);
    $instance->emailValidator = $container->get('email.validator');
    return $instance;
  }

  /**
   * Responds to email validation GET requests.
   *
   * One would typically expect validation requests to be POST, right? Well,
   * GET was chosen for two reasons.  First, GET requests are cacheable, so
   * in performance-critical applications, such as clientside validation
   * integrations, caching the metadata at the CDN layer is very attractive.
   * Second, the underlying API call to Neutrino also uses GET.  Speed at
   * every layer!
   *
   * @param string $email
   *   The email address to get validation information for.
   */
  public function get($email = NULL) {
    $metadata = $this->emailValidator->getAllValidationMetadata($email);
    return new ResourceResponse($metadata);
  }

}
